@@ -7,16 +7,20 @@
 #'
 #' @export
 sysinfo <- function() {
-  ## Built-in information
+  ## Built-in system information (character)
   sysinfo <- as.list(Sys.info())
   sysinfo$os <- .Platform$OS.type
   sysinfo$gui <- .Platform$GUI
   sysinfo$interactive <- interactive()
 
-  ## Additional information
+  ## Built-in system flags (logical)
   sysinfo$ess <- is_ess()
-  sysinfo$rice <- is_rice()
-  sysinfo$rstudio <- is_rstudio()
+  sysinfo$microsoftr <- is_microsoftr()
+  sysinfo$pqr <- is_pqr()
+  sysinfo$rtichoke <- is_rtichoke()
+  sysinfo$rice <- sysinfo$rtichoke  ## Renamed February 2018
+  sysinfo$rstudio <- is_rstudio_console()
+  sysinfo$rstudioterm <- is_rstudio_terminal()
   sysinfo$wine <- is_wine()
 
   sysinfo
