@@ -1,7 +1,7 @@
-renviron <- startup:::renviron
-rprofile <- startup:::rprofile
-renviron_d <- startup:::renviron_d
-rprofile_d <- startup:::rprofile_d
+renviron <- startup::renviron
+rprofile <- startup::rprofile
+renviron_d <- startup::renviron_d
+rprofile_d <- startup::rprofile_d
 
 message("*** startup() ...")
 
@@ -26,19 +26,17 @@ rprofile_d(paths = paths, skip = FALSE, dryrun = TRUE)
 message("*** rprofile_d() ... DONE")
 
 
-message("*** startup() - deprecated ...")
+message("*** startup() - defunct ...")
 
 paths <- system.file(".Renviron.d", package = "startup")
-res <- tryCatch(renviron(paths = paths, skip = FALSE), warning = identity)
-stopifnot(inherits(res, "simpleWarning"))
-renviron(paths = paths, skip = FALSE, dryrun = TRUE)
+res <- tryCatch(renviron(paths = paths, skip = FALSE), error = identity)
+stopifnot(inherits(res, "error"))
 
 paths <- system.file(".Rprofile.d", package = "startup")
-res <- tryCatch(rprofile(paths = paths, skip = FALSE), warning = identity)
-stopifnot(inherits(res, "simpleWarning"))
-rprofile(paths = paths, skip = FALSE, dryrun = TRUE)
+res <- tryCatch(rprofile(paths = paths, skip = FALSE), error = identity)
+stopifnot(inherits(res, "error"))
 
-message("*** startup() - deprecated ... DONE")
+message("*** startup() - defunct ... DONE")
 
 
 message("*** startup() - exceptions ...")
